if benchmark == "ein" {
cap log close
log using $log/03_dataclean.log, replace
}

******* 3. Cleaning the data ***************************************************
* Note that there are two different levels
* 1st level: data cleaning unrelated to the stabilization lag k
* 2nd level: data cleaning including the stabilization lag k (delete all establishments that existed for a shorter time period than k)

use $data/bhp_raw_`=scalar(start)'_`=scalar(end)'.dta, clear

*** 3.1 Exclude specific sectors

* Exclude the agricultural sector
drop if sector93 == 1
drop if sector93 == 2
drop if sector08 == 1

* Exclude energy and water supply
drop if sector93 == 5 //energy and water supply
drop if sector08 == 4 //energy supply
drop if w08_3_gen == 360 //water supply (Part of sector08=5)

* Exclude public administration
drop if sector93 == 12
drop if sector08 == 15 

* Exclude private households and exterritorial organisations
drop if sector93 == 16
drop if sector93 == 17 
drop if sector08 == 20

* Delete missing values of industrial classifications
drop if w08_3_gen == .z & w93_3_gen	== .z 

drop w08_3_gen w93_3_gen


*** 3. 2 Drop establishments that have a gap in their observations
gen byte luecke = 0
by betnr: replace luecke = 1 if betnr[_n] == betnr[_n+1] & jahr[_n+1] - jahr[_n] != 1 
replace luecke = 1 if betnr[_n] == betnr[_n-1] & luecke[_n-1] == 1
replace luecke = 1 if betnr[_n] == betnr[_n+1] & luecke[_n+1] == 1
drop if luecke == 1 
drop if betnr[_n] != betnr[_n+1] & betnr[_n] != betnr[_n-1] 
drop luecke



***************************************************
*** Clean data for descriptive statistics *********
save $data/bhp_clean_descstat.dta, replace
***************************************************


*** 3.3 Delete establishments that existed for a shorter time period than k
drop if B>D 


*** 3.4 Delete East German establishments before 1993+k 
* because East German data are only reliable since 1993
drop if ao_bula >= 11 & jahr < (1993+k)


***************************************************
* Datensatz auch um k bereinigt *******************
save $data/bhp_clean_k_descstat.dta, replace
***************************************************

xtsum

* Reduce the amount of variables to reduce the required computing capacity
drop az_ges az_gf lohnsumme_vz vzae betnr_vor status_vor Bestehen Bestehen_all

if creades == "ein" {
	drop sector93
	save $data/bhp_clean_sector08, replace
	}

drop grd_jahr schl_jahr

if bundeslaender == "aus" & creades == "aus" {
drop ao_bula
}

if WZweiganalyse == "ein" {
	save $data/bhp_clean_wz, replace
	}

if  WZweiganalyse == "aus" & creades == "aus" {
	drop sector93 sector08
	save $data/bhp_clean_`=scalar(start)'_`=scalar(end)'.dta, replace
}

clear
