cap log close
log using $log/04_descstat.log, replace


use $data/bhp_clean_descstat.dta, clear

* 4.1 descriptive statistics of plants (Cp. Aghion et al JEEA Table 2)
use $data/bhp_clean_descstat.dta, clear
gen dummy = 1
sort jahr
by jahr: egen gesamt = sum(dummy)
drop dummy
by jahr: egen avg_fte = mean(vzae)
by jahr: egen avg_headcount = mean(az_ges)
by jahr: gen countdummy = _n
keep if countdummy == 1
drop countdummy

* Explanation for the FDZ:
* This is the descriptive statistics of our clean dataset. 
* The first column shows the year, 
* the second column shows the amount of establishments (which is then also the number of cases) 
* the third column shows the average amount of full-time equivalents, and 
* the fourth column shows the average number of employees.

list jahr gesamt avg_fte avg_headcount



* 4.2 Growth of number of employees

use $data/bhp_clean_descstat.dta, clear
drop if Bestehen == . 

* Average growth of total employment
gen besch_growth = .
by betnr: replace besch_growth = (az_ges[_n] - az_ges[_n-1])/az_ges[_n-1]
egen besch_growth_mean = mean(besch_growth), by(Bestehen)

* Case numbers:
sort Bestehen
by Bestehen: egen fallzahl_wachstum = count(_n)
bysort Bestehen: gen hilfsvariable = _n
keep if hilfsvariable == 1
drop hilfsvariable

* Explanation for the FDZ:
* Here, we calculate the average growth rate of total employment by age of the establishment.
* The number of cases is thus the number of establishments of a given age (displayed in the third column).
* The first column shows the age, the second column average employment growth

list Bestehen besch_growth_mean fallzahl_wachstum


* 4.3 Employment share by age (Cp. Aghion et (2018) section 4.1, Figure 6)


* Calculation

forval y = 1975/2017 {
	use $data/bhp_clean_descstat.dta, clear //no cleaning with respect to k
	keep if jahr == `y'
	drop if Bestehen == . //only real new formations are included
	
	egen gesamt = sum(az_ges)

	gen age0_5_D = 0
	replace age0_5_D = az_ges if Bestehen < 6
	egen age0_5 = sum(age0_5_D)
	drop age0_5_D
	gen age0_5_share = age0_5/gesamt
	drop age0_5

	gen age6_10_D = 0
	replace age6_10_D = az_ges if Bestehen > 5 & Bestehen < 11
	egen age6_10 = sum(age6_10_D)
	drop age6_10_D
	gen age6_10_share = age6_10/gesamt
	drop age6_10

	gen age11_15_D = 0
	replace age11_15_D = az_ges if Bestehen > 10 & Bestehen < 16
	egen age11_15 = sum(age11_15_D)
	drop age11_15_D
	gen age11_15_share = age11_15/gesamt
	drop age11_15

	gen age16_20_D = 0
	replace age16_20_D = az_ges if Bestehen > 15 & Bestehen < 21
	egen age16_20 = sum(age16_20_D)
	drop age16_20_D
	gen age16_20_share = age16_20/gesamt
	drop age16_20

	gen age21_25_D = 0
	replace age21_25_D = az_ges if Bestehen > 20 & Bestehen < 26
	egen age21_25 = sum(age21_25_D)
	drop age21_25_D
	gen age21_25_share = age21_25/gesamt
	drop age21_25

	gen age26_D = 0
	replace age26_D = az_ges if Bestehen > 25
	egen age26 = sum(age26_D)
	drop age26_D
	gen age26_share = age26/gesamt
	drop age26

	gen fallzahlen = gesamt

	gen number = _n
	keep if number == 1
	keep jahr age0_5_share age6_10_share age11_15_share age16_20_share age21_25_share age26_share fallzahlen
	save "$data/empshare`y'", replace
	}

	
* Append datasets that contain the results
use $data/empshare1975, clear
forval y = 1976/2017 {
	append using $data/empshare`y'.dta
	}
	

* Display results

* Explanation for the FDZ:
* In this section, the employment share by age is calculated for each year. 
* There are 6 age groups: 0-5, 6-10, 11-15, 16-20, 21-25, older than 25
* The calculation is done as follows, the amount of employees in each
* group is counted and then divided by total amount of employees. 
* Thus, the number of cases is equal to the total amount of employees, which 
* is the same in all age groups.
* In the following table, the first column is the year, the second column the number of cases,
* the columns three to eight are the age gruoups.
* Note that we only look at establishments that are really new foundations.

list jahr fallzahlen age0_5_share age6_10_share age11_15_share age16_20_share age21_25_share age26_share




* 4.4 average employment (Cp. Aghion et (2018) section 4.1, Figure 7)
* Size of plants measured in total headcounts by age

* Calculation
use $data/bhp_clean_descstat.dta, clear

* For a specific year:
* keep if jahr == 2016
* Note: Figure 3 is done for a specific year

sort Bestehen
drop if Bestehen == .
by Bestehen: egen avgsize = mean(az_ges)
gen gesamt_D =1
by Bestehen: egen fallzahlen = sum(gesamt_D)
keep Bestehen avgsize fallzahlen
by Bestehen: gen number_D = _n
keep if number_D == 1
drop number_D

* Display results

* Explanation for the FDZ:
* Here, we calculate the size of establishments by age in terms of employment.
* The calculation is done as follows, the average amount of employees is counted 
* by age of establishments.
* The number of cases is the total amount of establishments that exist for each age.
* The first column of the table reports the age, the second one the average 
* amount of employees, and the third one the number of cases.

list Bestehen avgsize fallzahlen



* 4.5 Entry and exit rates 

* Calculation
use $data/bhp_clean_descstat.dta, clear
gen austritte = 0
replace austritte = 1 if austritt == 4 | austritt == 5 | austritt == 6
replace austritte = 0 if jahr != schl_jahr
sort jahr
by jahr: egen austritte_gesamt = sum(austritte)
gen eintritte = 0
replace eintritte = 1 if eintritt == 4 | eintritt == 5 | eintritt == 6
replace eintritte = 0 if jahr != grd_jahr
sort jahr
by jahr: egen eintritte_gesamt = sum(eintritte)
gen gesamt_D =1
by jahr: egen gesamt = sum(gesamt_D)
keep jahr gesamt eintritte_gesamt austritte_gesamt
by jahr: gen number_D = _n
keep if number_D == 1
drop number_D
compress

* Display results

* Explanation for the FDZ:
* Here, we count how many establishments exist in each year, and how many
* real entries and real exits there are in each year.
* The first column of table is the year, the second one the amount of
* establishments, the third one the amount of entries and the fourth one 
* the amount of exits.

list jahr gesamt eintritte_gesamt austritte_gesamt
