if benchmark == "ein" {
	cap log close
	log using $log/06_mgcalc.log, replace
	use $data/bhp_mgaux_`=scalar(start)'_`=scalar(end)'.dta, clear
	}
	
	
******* 6.1 Calculate Missing Growth *******************************************

forval y = `=scalar(start)+1'/`=scalar(end)-1' {
	gen mg`y' = (1/(sigma-1))* (ln(x_c_`y-1'/(x_c_`y-1'+e_`y-1'))-ln(x_s_`y'/(x_s_`y'+f_`y')))
}


* Create only one variable that contains the results
gen mg = .
forval y = `=scalar(start)+1'/`=scalar(end)-1' {
	replace mg = mg`y' if jahr == `y'
	drop mg`y'
	}
compress


******* 6.2 Calculate Market shares and number of cases ************************
if benchmark == "ein" {

* Market share of exiting plants ("e")
forval y = `=scalar(start)'/`=scalar(end)-1' {
	gen mks_austritte`y' = e_`y'/(x_c_`y'+e_`y')
}
gen mks_austritte`=scalar(end)' = e_`=scalar(end)' / (f_`=scalar(end)' + x_s_`=scalar(end)') //last value

* Create only one variable that contains the results
gen mks_austritte = .
forval y = `=scalar(start)'/`=scalar(end)' {
	replace mks_austritte = mks_austritte`y' if jahr == `y'
	drop mks_austritte`y'
}

* Market share of entering plants ("e")
forval y = `=scalar(start)+1'/`=scalar(end)' {
	gen mks_eintritte`y' = f_`y'/(x_s_`y'+f_`y')
}
gen mks_eintritte`=scalar(start)' = f_`=scalar(start)'/(x_c_`=scalar(start)'+e_`=scalar(start)') //last value

* Create only one variable that contains the results
gen mks_eintritte = .
forval y = `=scalar(start)'/`=scalar(end)' {
	replace mks_eintritte = mks_eintritte`y' if jahr == `y'
	drop mks_eintritte`y'
}
compress
}

* delete all auxiliar variables that are not needed anymore
forval y = `=scalar(start)'/`=scalar(end)' {
	capture drop x_s_`y'
	capture drop f_`y'
	capture drop x_c_`y'
	capture drop e_`y'
}


* market share of continuer (active in t and t+1)
gen byte continuerdummy = 0
replace continuerdummy = 1 if betnr[_n] == betnr[_n+1] & proxy[_n]>0 & proxy[_n+1]>0 & jahr[_n+1]-jahr[_n] == 1
gen byte austrittedummy = 0
replace austrittedummy = 1 if austritt == 4 | austritt == 5 | austritt == 6
gen byte mks_austritte_D = 0
replace mks_austritte_D = 1 if austrittedummy == 1 | continuerdummy == 1
drop continuerdummy austrittedummy austritt
compress

* market share of stayers (active in t-1 and t)
gen byte stayerdummy = 0
replace stayerdummy = 1 if betnr[_n] == betnr[_n-1] & proxy[_n]>0 & proxy[_n-1]>0 & jahr[_n] - jahr[_n-1] == 1 
gen byte eintrittedummy = 0
replace eintrittedummy = 1 if eintritt == 4 | eintritt == 5 | eintritt == 6
gen byte mks_eintritte_D = 0
replace mks_eintritte_D = 1 if eintrittedummy == 1 | stayerdummy == 1
drop stayerdummy eintrittedummy eintritt
drop proxy
compress

* Create only one variable for market share of continuer and of stayers
sort jahr betnr
by jahr: egen fallzahlen_mks_eintritte = count(_n) if mks_eintritte_D == 1
by jahr: egen fallzahlen_mks_austritte = count(_n) if mks_austritte_D == 1
sort betnr jahr
drop mks_austritte_D mks_eintritte_D
compress

* Prepare data to display results
drop if fallzahlen_mks_eintritte == .
drop if fallzahlen_mks_austritte == .
bysort jahr: gen keep = _n
keep if keep == 1
drop keep
drop betnr

* Number of cases for Missing Growth
gen fallzahlen_mks_austritte_H = fallzahlen_mks_austritte 
gsort -jahr
replace fallzahlen_mks_austritte_H = fallzahlen_mks_austritte_H[_n+1] 
sort jahr
egen fallzahlen_mg = rowtotal(fallzahlen_mks_eintritte fallzahlen_mks_austritte_H)
drop fallzahlen_mks_austritte_H
compress



******* 6.3 Display results *********************************
* only for the benchmark analysis, all other results are diyplayed in the corresponding do-files

* Explanation for the FDZ
* A first result in missing growth (MG)
* MG is one number per year that is calculated using the formula in section 6.1
* For the formula, two market shares are used:
* the market share of Stayer: x_s_`y'/(x_s_`y'+f_`y')
* and the market share of continuers: x_c_`y-1'/(x_c_`y-1'+e_`y-1')
* The variables were calculated in the do-file 05_mgvariables.
* The number of cases were caluclated in section 6.2.
* A second result are the market shares, which are also calculated in 6.2
* together with their number of cases


if benchmark == "ein" {
	disp k sigma Proxyauswahl regionenauswahl 
	list jahr mg fallzahlen_mg
	list jahr mks_eintritte fallzahlen_mks_eintritte mks_austritte fallzahlen_mks_austritte
	table jahr, contents(mean mks_eintritte mean fallzahlen_mks_eintritte mean mks_austritte mean fallzahlen_mks_austritte)
	drop mks_eintritte mks_austritte
	}
