cap log close
log using $log/11_creades.log, replace


* 11. Creative destruction in sectors and departments (Bundesländer)
* Note that this file only gives the necessary data, the calculation of creative destruction has to be done by hand


* 11.1 Creative destruction in sectors

* 11.1.1 Calculation

forval s = 2/19 {
	* clean data also with respect to k
	use $data/bhp_clean_sector08, clear
	* clean data, but not with respect to k
	*use $data/bhp_clean_descstat.dta, clear
	drop if jahr < 1980
	drop if jahr == 2017
	drop if sector08 != `s'
	
	capture gen austritteD = 0
	capture replace austritteD = 1 if austritt == 4 | austritt == 5 | austritt == 6
	capture replace austritteD = 0 if jahr != schl_jahr
	capture sort jahr
	capture by jahr: egen austritte_gesamt = sum(austritteD)
	capture drop austritteD
	
	capture gen eintritteD = 0
	capture replace eintritteD = 1 if eintritt == 4 | eintritt == 5 | eintritt == 6
	capture replace eintritteD = 0 if jahr != grd_jahr
	capture sort jahr
	capture by jahr: egen eintritte_gesamt = sum(eintritteD)
	capture drop eintritteD
	
	capture gen gesamt_D =1
	capture by jahr: egen gesamt = sum(gesamt_D)
	
	capture gen fallzahlen`s' = gesamt
	capture gen austritte`s' = austritte_gesamt
	capture gen eintritte`s' = eintritte_gesamt

	capture keep jahr fallzahlen`s' austritte`s' eintritte`s' 
	capture by jahr: gen number_D = _n
	capture keep if number_D == 1
	capture drop number_D
	compress
	save "$data/resultswz08cd_`s'.dta", replace
	} 

* 11.1.2 Append datasets that contain the results
use "$data/resultswz08cd_2.dta"
forval y = 3/19 {
	merge m:1 jahr using $data/resultswz08cd_`y'.dta
	drop _merge
	}
	

* 11.1.3 Display results

* Explanation for the FDZ:
* This do-file reports the necessary data to calculate creative destruction.
* This inlcudes the total amount of establishments, the amount of establishment 
* entries and the amount of establishment exits.
* This is counted here for each sector in each year.
* The loop in section 11.1.1 first identifies all establishments that 
* really newly enter or really exit the market, and then counts it.
* The first column is the year, the second column the total amount of establishments, 
* the third one the establishments that exit and the fourth one the establishments
* that entered the market.

forval y = 2/3 {
	list jahr fallzahlen`y' austritte`y' eintritte`y'
	}

forval y = 5/14 {
	list jahr fallzahlen`y' austritte`y' eintritte`y'
	}
	
forval y = 16/19 {
	list jahr fallzahlen`y' austritte`y' eintritte`y'
	}


* delete files that are not used anymore
forval y = 2/19 {
	capture erase $data/resultswz08cd_`y'.dta
	}



	
* 11.2 Creative destruction in departments (Bundesländer)

* 11.2.1 Calculation

forval s = 1/16 {	
	* clean data also with respect to k
	use $data/bhp_clean_sector08, clear
	* clean data, but not with respect to k
	* use $data/bhp_clean_descstat.dta, clear
	drop if jahr < 1980
	drop if jahr == 2017
	
	drop if ao_bula != `s'
	
	capture gen austritteD = 0
	capture replace austritteD = 1 if austritt == 4 | austritt == 5 | austritt == 6
	* Note: to replicate table 4, one has to leave out the category austritt == 6, so use the following line instead
	* capture replace austritteD = 1 if austritt == 4 | austritt == 5
	capture replace austritteD = 0 if jahr != schl_jahr
	capture sort jahr
	capture by jahr: egen austritte_gesamt = sum(austritteD)
	
	capture gen eintritteD = 0
	capture replace eintritteD = 1 if eintritt == 4 | eintritt == 5 | eintritt == 6
	* Note: to replicate table 4, one has to leave out the category eintritt == 6, so use the following line instead
	* capture replace eintritteD = 1 if eintritt == 4 | eintritt == 5
	capture	replace eintritteD = 0 if jahr != grd_jahr
	capture sort jahr
	capture by jahr: egen eintritte_gesamt = sum(eintritteD)
	
	capture gen gesamt_D =1
	capture by jahr: egen gesamt = sum(gesamt_D)
	capture gen fallzahlen`s' = gesamt
	capture gen austritte`s' = austritte_gesamt
	capture gen eintritte`s' = eintritte_gesamt
	capture keep jahr fallzahlen`s' austritte`s' eintritte`s'
	capture by jahr: gen number_D = _n
	capture keep if number_D == 1
	capture drop number_D
	compress
	save "$data/results_cd_bula`s'.dta", replace
	} 

* 11.2.2 Append datasets that contain the results
use "$data/results_cd_bula1.dta"
forval y = 2/16 {
	merge m:1 jahr using $data/results_cd_bula`y'.dta
	drop _merge
	}
	

* 11.2.3 Display results

* Explanation for the FDZ: 
* This is similar to the calculations in section 11.2
* The only difference is that here it is counted by departments
* (and not by sectors).

forval y = 1/16 {
	list jahr fallzahlen`y' austritte`y' eintritte`y'
	}

	
* delete files that are not used anymore
forval y = 1/16 {
	capture erase $data/results_cd_bula`y'.dta
	}

clear
