cap log close
log using $log/12_bundesland.log, replace

*** 12. MG in each department (Bundesland)

* 12.1 Calculations

forval y = 1/16 {
	use $data/bhp_panel_01_dataprep.dta, clear
	do "$prog/02_auxvariables.do"
	do "$prog/03_dataclean.do"
	use $data/bhp_clean_`=scalar(start)'_`=scalar(end)'.dta, clear
	drop if ao_bula != `y'	
	do "$prog/05_mgvariables.do"	
	do "$prog/06_mgcalc.do"
	rename mg mg_`y'
	rename fallzahlen_mg fallzahlen_mg_`y'
	compress
	save "$data/results_`y'.dta", replace
	clear
	}

capture erase "$data/bhp_panel_`=scalar(start)'_`=scalar(end)'.dta" 

* 12.2 Append datasets that contain the results
use "$data/results_1.dta"
forval y = 2/16 {
	merge m:1 jahr using $data/results_`y'.dta
	drop _merge
	}

* Delete values in East Germany before 1998, because analysis is only possible
* since 1993+1+k, which is 1998 here.
forval y = 11/16 {
	replace mg_`y' = 0 if jahr<1998
	} 



* 12.3 Display results

* Explanation for the FDZ
* In this do-file, yearly missing growth is calculated in each department (Bundesland).
* The calculation of MG is in the do-file 06_mgcalc in section 6.1, this do-file
* uses the auxiliar variables that are created in the do-file 05_mgvariables.
* The formula consists of two market shares, namely the market shares of the 
* so-called stayers (establishments that already existed in the previous period):
* x_s_`y'/(x_s_`y'+f_`y'),
* and so-called the continuers (establishments that will exist also next period):
* x_c_`y-1'/(x_c_`y-1'+e_`y-1').
* The number of cases are also calculated in the do-file 06_mgcalc section 6.3.
* The first column is the year, the second one MG and the third one the number 
* of cases.

forval y = 1/16 {
	list jahr mg_`y' fallzahlen_mg_`y'
	}

* delete files that are not used anymore
forval y = 1/16 {
	capture erase $data/results_`y'.dta
	}
