* master file
* Stata 14
* Data version: bhp_7517_m06_p50_v1

* Note: adjust path in profile in Stata folder

version 14          // use the Stata version currently used at FDZ to avoid errors when using a newer Stata version on your personal computer
                    // set older version only if you need downward compatible execution of Stata commands or ado files
clear
set more off        // no --more-- messages

*set linesize 120   // maximum linesize Internal Use
set linesize 255    // maximum linesize Presentation/Publication


********************************************************************************
******* Pre-Settings ***********************************************************

* First year of the analysis
scalar start = 1975 //note that the first year with MG is the first year with information about entry rates plus lag k, so here it is 1980 for k=4.

* Last year of the analysis
scalar end = 2017 //note that MG can only be calculated until the last year minus one, because one has to know if an establishment still exist in the next year, so here it is 2016.

scalar sigma = 4 //sigma can be varied algebraically afterwards


********************************************************************************
******* Choosing one analysis **************************************************

//Note that it is recommended to choose only one analysis at a time to avoid that log-files are overwriting each other.

* Benchmark analysis
scalar benchmark = "ein"

* sectoral analysis including sectoral weighted MG
scalar WZweiganalyse = "aus"

* Robustness of the stabilization lag k (Note that benchmark is k=4)
scalar Krobustness = "aus"
scalar kmin = 3
scalar kmax = 5
*! Note that this also includes the results of the benchmark analysis

* Robustness of the proxies (Note that benchmark is proxy=az_ges)
scalar Proxyrobustness = "aus" 

* East-West analysis
scalar Regionenanalyse = "aus"

* Descriptive statistics and plant dynamics
scalar descstat = "aus"

* Creative destruction in sectors and departments ("Bundesländer")
scalar creades = "aus"

* Department (Bundesländer) analysis
scalar bundeslaender = "aus"


********************************************************************************
********************************************************************************

do "$prog/01_dataprep.do"

if benchmark == "ein" {
	scalar k = 4
	scalar Proxyauswahl = "az_ges"
	scalar regionenauswahl = "gesamt"
	do "$prog/02_auxvariables.do"
	do "$prog/03_dataclean.do"
	do "$prog/05_mgvariables.do"
	do "$prog/06_mgcalc.do" 
	clear
	}


if WZweiganalyse == "ein" {
	scalar k = 4
	scalar Proxyauswahl = "az_ges"
	scalar regionenauswahl = "gesamt"
	do "$prog/07_wzweige.do"
	clear
	}

if Krobustness == "ein" {
		scalar Proxyauswahl = "az_ges" 
		scalar regionenauswahl = "gesamt"
		do "$prog/08_k.do"
		clear
}

if Proxyrobustness == "ein" {
	scalar k = 4
	scalar regionenauswahl = "gesamt"
	do "$prog/09_proxy.do"
	clear
	}

if Regionenanalyse == "ein" {
	scalar k = 4
	scalar Proxyauswahl = "az_ges"
	do "$prog/10_region.do"
	clear
	}

if descstat == "ein" {
	scalar k = 4
	scalar Proxyauswahl = "az_ges"
	scalar regionenauswahl = "gesamt"
	do "$prog/02_auxvariables.do"
	do "$prog/03_dataclean.do"
	do "$prog/04_descstat.do"
	clear
	}

if creades == "ein" {
	scalar k = 4
	scalar Proxyauswahl = "az_ges"
	scalar regionenauswahl = "gesamt"
	do "$prog/02_auxvariables.do"
	do "$prog/03_dataclean.do"
	do "$prog/11_creades.do"
	clear
	}
	
	
if bundeslaender == "ein" {
	scalar k = 4
	scalar Proxyauswahl = "az_ges"
	scalar regionenauswahl = "gesamt"
	do "$prog/12_bundesland.do"
	clear
	}


do "$prog/13_cleanup.do"

